@@ -20,7 +20,7 @@ bearing <- function(p1, p2, a=6378137, f=1/298.257223563) {
 	}
 	
 	p <- cbind(p1[,1], p1[,2], p2[,1], p2[,2])	
-	r <- .Call("_inversegeodesic", as.double(p[,1]), as.double(p[,2]), as.double(p[,3]), as.double(p[,4]), as.double(a[1]), as.double(f[1]), PACKAGE='geosphere')
+	r <- .inversegeodesic(as.double(p[,1]), as.double(p[,2]), as.double(p[,3]), as.double(p[,4]), as.double(a[1]), as.double(f[1]))
 	r <- matrix(r, ncol=3, byrow=TRUE)
 	if (addNA) {
 		c(r[, 2], NA)
